@@ -13,9 +13,10 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-import re
 from collections import namedtuple
+from datetime import timedelta
 from inspect import getdoc, isclass
+from typing import Optional, List
 
 from robot.api import logger
 from robot.errors import DataError
@@ -24,29 +25,33 @@ from robot.utils import is_string
 from robot.utils.importer import Importer
 
 from robotlibcore import DynamicCore
+from selenium.webdriver.remote.webdriver import WebDriver
+from selenium.webdriver.remote.webelement import WebElement
 
 from SeleniumLibrary.base import LibraryComponent
 from SeleniumLibrary.errors import NoOpenBrowser, PluginError
-from SeleniumLibrary.keywords import (AlertKeywords,
-                                      BrowserManagementKeywords,
-                                      CookieKeywords,
-                                      ElementKeywords,
-                                      FormElementKeywords,
-                                      FrameKeywords,
-                                      JavaScriptKeywords,
-                                      RunOnFailureKeywords,
-                                      ScreenshotKeywords,
-                                      SelectElementKeywords,
-                                      TableElementKeywords,
-                                      WaitingKeywords,
-                                      WebDriverCache,
-                                      WindowKeywords)
+from SeleniumLibrary.keywords import (
+    AlertKeywords,
+    BrowserManagementKeywords,
+    CookieKeywords,
+    ElementKeywords,
+    FormElementKeywords,
+    FrameKeywords,
+    JavaScriptKeywords,
+    RunOnFailureKeywords,
+    ScreenshotKeywords,
+    SelectElementKeywords,
+    TableElementKeywords,
+    WaitingKeywords,
+    WebDriverCache,
+    WindowKeywords,
+)
 from SeleniumLibrary.keywords.screenshot import EMBED
 from SeleniumLibrary.locators import ElementFinder
-from SeleniumLibrary.utils import LibraryListener, timestr_to_secs, is_truthy
+from SeleniumLibrary.utils import LibraryListener, is_truthy, _convert_timeout
 
 
-__version__ = '4.5.0'
+__version__ = "5.0.0"
 
 
 class SeleniumLibrary(DynamicCore):
@@ -169,9 +174,10 @@ class SeleniumLibrary(DynamicCore):
 
     === Implicit XPath strategy ===
 
-    If the locator starts with ``//`` or ``(//``, the locator is considered
-    to be an XPath expression. In other words, using ``//div`` is equivalent
-    to using explicit ``xpath://div``.
+    If the locator starts with ``//``  or multiple opening parenthesis in front
+    of the ``//``, the locator is considered to be an XPath expression. In other
+    words, using ``//div`` is equivalent to using explicit ``xpath://div`` and
+    ``((//div))`` is equivalent to using explicit ``xpath:((//div))``
 
     Examples:
 
@@ -179,6 +185,32 @@ class SeleniumLibrary(DynamicCore):
     | `Click Element` | (//div)[2]           |
 
     The support for the ``(//`` prefix is new in SeleniumLibrary 3.0.
+    Supporting multiple opening parenthesis is new in SeleniumLibrary 5.0.
+
+    === Chaining locators ===
+
+    It is possible chain multiple locators together as single locator. Each chained locator must start with locator
+    strategy. Chained locators must be separated with single space, two greater than characters and followed with
+    space. It is also possible mix different locator strategies, example css or xpath. Also a list can also be
+    used to specify multiple locators. This is useful, is some part of locator would match as the locator separator
+    but it should not. Or if there is need to existing WebElement as locator.
+
+    Although all locators support chaining, some locator strategies do not abey the chaining. This is because
+    some locator strategies use JavaScript to find elements and JavaScript is executed for the whole browser context
+    and not for the element found be the previous locator. Chaining is supported by locator strategies which
+    are based on Selenium API, like `xpath` or `css`, but example chaining is not supported by `sizzle` or `jquery
+
+    Examples:
+    | `Click Element` | css:.bar >> xpath://a | # To find a link which is present after an element with class "bar" |
+
+    List examples:
+    | ${locator_list} =             | `Create List`   | css:div#div_id            | xpath://*[text(), " >> "] |
+    | `Page Should Contain Element` | ${locator_list} |                           |                           |
+    | ${element} =                  | Get WebElement  | xpath://*[text(), " >> "] |                           |
+    | ${locator_list} =             | `Create List`   | css:div#div_id            | ${element}                |
+    | `Page Should Contain Element` | ${locator_list} |                           |                           |
+
+    Chaining locators in new in SeleniumLibrary 5.0
 
     == Using WebElements ==
 
@@ -350,32 +382,13 @@ class SeleniumLibrary(DynamicCore):
 
     = Boolean arguments =
 
-    Some keywords accept arguments that are handled as Boolean values true or
-    false. If such an argument is given as a string, it is considered false if
-    it is either empty or case-insensitively equal to ``false``, ``no``, ``off``,
-     ``0`` or ``none``. Other strings are considered true regardless of their value and
-    other argument types are tested using the same
-    [https://docs.python.org/3/library/stdtypes.html#truth-value-testing|rules as in Python].
+    Starting from 5.0 SeleniumLibrary relies on Robot Framework to perform the
+    boolean conversion based on keyword arguments [https://docs.python.org/3/library/typing.html|type hint].
+    More details in Robot Framework
+    [http://robotframework.org/robotframework/latest/RobotFrameworkUserGuide.html#supported-conversions|user guide]
 
-    True examples:
-
-    | `Set Screenshot Directory` | ${RESULTS} | persist=True    | # Strings are generally true.    |
-    | `Set Screenshot Directory` | ${RESULTS} | persist=yes     | # Same as the above.             |
-    | `Set Screenshot Directory` | ${RESULTS} | persist=${TRUE} | # Python True is true.           |
-    | `Set Screenshot Directory` | ${RESULTS} | persist=${42}   | # Numbers other than 0 are true. |
-
-    False examples:
-
-    | `Set Screenshot Directory` | ${RESULTS} | persist=False    | # String false is false.        |
-    | `Set Screenshot Directory` | ${RESULTS} | persist=no       | # Also string no is false.      |
-    | `Set Screenshot Directory` | ${RESULTS} | persist=NONE     | # String NONE is false.         |
-    | `Set Screenshot Directory` | ${RESULTS} | persist=${EMPTY} | # Empty string is false.        |
-    | `Set Screenshot Directory` | ${RESULTS} | persist=${FALSE} | # Python False is false.        |
-    | `Set Screenshot Directory` | ${RESULTS} | persist=${NONE}  | # Python None is false.         |
-
-    Note that prior to SeleniumLibrary 3.0, all non-empty strings, including
-    ``false``, ``no`` and ``none``, were considered true. Starting from
-    SeleniumLibrary 4.0, strings ``0`` and ``off`` are considered as false.
+    Please note SeleniumLibrary 3 and 4 did have own custom methods to covert
+    arguments to boolean values.
 
     = EventFiringWebDriver =
 
@@ -404,13 +417,19 @@ class SeleniumLibrary(DynamicCore):
 
     Plugin API is new SeleniumLibrary 4.0
     """
-    ROBOT_LIBRARY_SCOPE = 'GLOBAL'
+
+    ROBOT_LIBRARY_SCOPE = "GLOBAL"
     ROBOT_LIBRARY_VERSION = __version__
 
-    def __init__(self, timeout=5.0, implicit_wait=0.0,
-                 run_on_failure='Capture Page Screenshot',
-                 screenshot_root_directory=None, plugins=None,
-                 event_firing_webdriver=None):
+    def __init__(
+        self,
+        timeout=timedelta(seconds=5),
+        implicit_wait=timedelta(seconds=0),
+        run_on_failure="Capture Page Screenshot",
+        screenshot_root_directory: Optional[str] = None,
+        plugins: Optional[str] = None,
+        event_firing_webdriver: Optional[str] = None,
+    ):
         """SeleniumLibrary can be imported with several optional arguments.
 
         - ``timeout``:
@@ -429,10 +448,12 @@ class SeleniumLibrary(DynamicCore):
           Class for wrapping Selenium with
           [https://seleniumhq.github.io/selenium/docs/api/py/webdriver_support/selenium.webdriver.support.event_firing_webdriver.html#module-selenium.webdriver.support.event_firing_webdriver|EventFiringWebDriver]
         """
-        self.timeout = timestr_to_secs(timeout)
-        self.implicit_wait = timestr_to_secs(implicit_wait)
+        self.timeout = _convert_timeout(timeout)
+        self.implicit_wait = _convert_timeout(implicit_wait)
         self.speed = 0.0
-        self.run_on_failure_keyword = RunOnFailureKeywords.resolve_keyword(run_on_failure)
+        self.run_on_failure_keyword = RunOnFailureKeywords.resolve_keyword(
+            run_on_failure
+        )
         self._running_on_failure_keyword = False
         self.screenshot_root_directory = screenshot_root_directory
         self._resolve_screenshot_root_directory()
@@ -451,7 +472,7 @@ class SeleniumLibrary(DynamicCore):
             SelectElementKeywords(self),
             TableElementKeywords(self),
             WaitingKeywords(self),
-            WindowKeywords(self)
+            WindowKeywords(self),
         ]
         self.ROBOT_LIBRARY_LISTENER = LibraryListener()
         self._running_keyword = None
@@ -466,47 +487,41 @@ class SeleniumLibrary(DynamicCore):
         self._drivers = WebDriverCache()
         DynamicCore.__init__(self, libraries)
 
-    def run_keyword(self, name, args, kwargs):
+    def run_keyword(self, name: str, args: tuple, kwargs: dict):
         try:
             return DynamicCore.run_keyword(self, name, args, kwargs)
         except Exception:
             self.failure_occurred()
             raise
 
-    def get_keyword_tags(self, name):
+    def get_keyword_tags(self, name: str) -> list:
         tags = list(DynamicCore.get_keyword_tags(self, name))
         if name in self._plugin_keywords:
-            tags.append('plugin')
+            tags.append("plugin")
         return tags
 
-    def get_keyword_documentation(self, name):
-        if name == '__intro__':
+    def get_keyword_documentation(self, name: str) -> str:
+        if name == "__intro__":
             return self._get_intro_documentation()
         return DynamicCore.get_keyword_documentation(self, name)
 
     def _parse_plugin_doc(self):
-        Doc = namedtuple('Doc', 'doc, name')
+        Doc = namedtuple("Doc", "doc, name")
         for plugin in self._plugins:
-            yield Doc(doc=getdoc(plugin) or 'No plugin documentation found.',
-                      name=plugin.__class__.__name__)
+            yield Doc(
+                doc=getdoc(plugin) or "No plugin documentation found.",
+                name=plugin.__class__.__name__,
+            )
 
     def _get_intro_documentation(self):
-        intro = DynamicCore.get_keyword_documentation(self, '__intro__')
+        intro = DynamicCore.get_keyword_documentation(self, "__intro__")
         for plugin_doc in self._parse_plugin_doc():
-            intro += '\n\n'
-            intro = intro + '= Plugin: %s =' % plugin_doc.name + '\n\n'
-            intro = intro + plugin_doc.doc
-        return self._create_toc(intro)
+            intro = f"{intro}\n\n"
+            intro = f"{intro}= Plugin: {plugin_doc.name} =\n\n"
+            intro = f"{intro}{plugin_doc.doc}"
+        return intro
 
-    def _create_toc(self, intro):
-        toc = ['== Table of contents ==', '']
-        all_match = re.findall(r'(^\=\s)(.+)(\s\=$)', intro, re.MULTILINE)
-        for match in all_match:
-            toc.append('- `%s`' % match[1])
-        toc.extend(['- `Importing`', '- `Shortcuts`', '- `Keywords`'])
-        return intro.replace('%TOC%', '\n'.join(toc))
-
-    def register_driver(self, driver, alias):
+    def register_driver(self, driver: WebDriver, alias: str):
         """Add's a `driver` to the library WebDriverCache.
 
         :param driver: Instance of the Selenium `WebDriver`.
@@ -531,23 +546,26 @@ class SeleniumLibrary(DynamicCore):
             self._running_on_failure_keyword = True
             BuiltIn().run_keyword(self.run_on_failure_keyword)
         except Exception as err:
-            logger.warn("Keyword '%s' could not be run on failure: %s"
-                        % (self.run_on_failure_keyword, err))
+            logger.warn(
+                f"Keyword '{self.run_on_failure_keyword}' could not be run on failure: {err}"
+            )
         finally:
             self._running_on_failure_keyword = False
 
     @property
-    def driver(self):
+    def driver(self) -> WebDriver:
         """Current active driver.
 
         :rtype: selenium.webdriver.remote.webdriver.WebDriver
         :raises SeleniumLibrary.errors.NoOpenBrowser: If browser is not open.
         """
         if not self._drivers.current:
-            raise NoOpenBrowser('No browser is open.')
+            raise NoOpenBrowser("No browser is open.")
         return self._drivers.current
 
-    def find_element(self, locator, parent=None):
+    def find_element(
+        self, locator: str, parent: Optional[WebElement] = None
+    ) -> WebElement:
         """Find element matching `locator`.
 
         :param locator: Locator to use when searching the element.
@@ -562,7 +580,9 @@ class SeleniumLibrary(DynamicCore):
         """
         return self._element_finder.find(locator, parent=parent)
 
-    def find_elements(self, locator, parent=None):
+    def find_elements(
+        self, locator: str, parent: WebElement = None
+    ) -> List[WebElement]:
         """Find all elements matching `locator`.
 
         :param locator: Locator to use when searching the element.
@@ -574,21 +594,23 @@ class SeleniumLibrary(DynamicCore):
         :return: list of found `WebElement` or e,mpty if elements are not found.
         :rtype: list[selenium.webdriver.remote.webelement.WebElement]
         """
-        return self._element_finder.find(locator, first_only=False,
-                                         required=False, parent=parent)
+        return self._element_finder.find(
+            locator, first_only=False, required=False, parent=parent
+        )
 
     def _parse_plugins(self, plugins):
         libraries = []
-        importer = Importer('test library')
+        importer = Importer("test library")
         for parsed_plugin in self._string_to_modules(plugins):
             plugin = importer.import_class_or_module(parsed_plugin.module)
             if not isclass(plugin):
-                message = "Importing test library: '%s' failed." % parsed_plugin.module
+                message = f"Importing test library: '{parsed_plugin.module}' failed."
                 raise DataError(message)
-            plugin = plugin(self, *parsed_plugin.args,
-                            **parsed_plugin.kw_args)
+            plugin = plugin(self, *parsed_plugin.args, **parsed_plugin.kw_args)
             if not isinstance(plugin, LibraryComponent):
-                message = 'Plugin does not inherit SeleniumLibrary.base.LibraryComponent'
+                message = (
+                    "Plugin does not inherit SeleniumLibrary.base.LibraryComponent"
+                )
                 raise PluginError(message)
             self._store_plugin_keywords(plugin)
             libraries.append(plugin)
@@ -596,30 +618,30 @@ class SeleniumLibrary(DynamicCore):
 
     def _parse_listener(self, event_firing_webdriver):
         listener_module = self._string_to_modules(event_firing_webdriver)
-        listener_count = len(listener_module )
+        listener_count = len(listener_module)
         if listener_count > 1:
-            message = 'Is is possible import only one listener but there was %s listeners.' % listener_count
+            message = f"Is is possible import only one listener but there was {listener_count} listeners."
             raise ValueError(message)
         listener_module = listener_module[0]
-        importer = Importer('test library')
+        importer = Importer("test library")
         listener = importer.import_class_or_module(listener_module.module)
         if not isclass(listener):
-            message = "Importing test Selenium lister class '%s' failed." % listener_module.module
+            message = f"Importing test Selenium lister class '{listener_module.module}' failed."
             raise DataError(message)
         return listener
 
     def _string_to_modules(self, modules):
-        Module = namedtuple('Module', 'module, args, kw_args')
+        Module = namedtuple("Module", "module, args, kw_args")
         parsed_modules = []
-        for module in modules.split(','):
+        for module in modules.split(","):
             module = module.strip()
-            module_and_args = module.split(';')
+            module_and_args = module.split(";")
             module_name = module_and_args.pop(0)
             kw_args = {}
             args = []
             for argument in module_and_args:
-                if '=' in argument:
-                    key, value = argument.split('=')
+                if "=" in argument:
+                    key, value = argument.split("=")
                     kw_args[key] = value
                 else:
                     args.append(argument)
