@@ -15,18 +15,17 @@
 # limitations under the License.
 
 import os
+from typing import Optional
 
 from robot.libraries.BuiltIn import BuiltIn
 
 from SeleniumLibrary.base import LibraryComponent, keyword
 from SeleniumLibrary.errors import ElementNotFound
-from SeleniumLibrary.utils import is_noney, is_truthy
 
 
 class FormElementKeywords(LibraryComponent):
-
     @keyword
-    def submit_form(self, locator=None):
+    def submit_form(self, locator: Optional[str] = None):
         """Submits a form identified by ``locator``.
 
         If ``locator`` is not given, first form on the page is submitted.
@@ -34,40 +33,42 @@ class FormElementKeywords(LibraryComponent):
         See the `Locating elements` section for details about the locator
         syntax.
         """
-        self.info("Submitting form '%s'." % locator)
-        if is_noney(locator):
-            locator = 'tag:form'
-        element = self.find_element(locator, tag='form')
+        self.info(f"Submitting form '{locator}'.")
+        if locator is None:
+            locator = "tag:form"
+        element = self.find_element(locator, tag="form")
         element.submit()
 
     @keyword
-    def checkbox_should_be_selected(self, locator):
+    def checkbox_should_be_selected(self, locator: str):
         """Verifies checkbox ``locator`` is selected/checked.
 
         See the `Locating elements` section for details about the locator
         syntax.
         """
-        self.info("Verifying checkbox '%s' is selected." % locator)
+        self.info(f"Verifying checkbox '{locator}' is selected.")
         element = self._get_checkbox(locator)
         if not element.is_selected():
-            raise AssertionError("Checkbox '%s' should have been selected "
-                                 "but was not." % locator)
+            raise AssertionError(
+                f"Checkbox '{locator}' should have been selected but was not."
+            )
 
     @keyword
-    def checkbox_should_not_be_selected(self, locator):
+    def checkbox_should_not_be_selected(self, locator: str):
         """Verifies checkbox ``locator`` is not selected/checked.
 
         See the `Locating elements` section for details about the locator
         syntax.
         """
-        self.info("Verifying checkbox '%s' is not selected." % locator)
+        self.info(f"Verifying checkbox '{locator}' is not selected.")
         element = self._get_checkbox(locator)
         if element.is_selected():
-            raise AssertionError("Checkbox '%s' should not have been "
-                                 "selected." % locator)
+            raise AssertionError(f"Checkbox '{locator}' should not have been selected.")
 
     @keyword
-    def page_should_contain_checkbox(self, locator, message=None, loglevel='TRACE'):
+    def page_should_contain_checkbox(
+        self, locator: str, message: Optional[str] = None, loglevel: str = "TRACE"
+    ):
         """Verifies checkbox ``locator`` is found from the current page.
 
         See `Page Should Contain Element` for an explanation about ``message``
@@ -76,10 +77,12 @@ class FormElementKeywords(LibraryComponent):
         See the `Locating elements` section for details about the locator
         syntax.
         """
-        self.assert_page_contains(locator, 'checkbox', message, loglevel)
+        self.assert_page_contains(locator, "checkbox", message, loglevel)
 
     @keyword
-    def page_should_not_contain_checkbox(self, locator, message=None, loglevel='TRACE'):
+    def page_should_not_contain_checkbox(
+        self, locator: str, message: Optional[str] = None, loglevel: str = "TRACE"
+    ):
         """Verifies checkbox ``locator`` is not found from the current page.
 
         See `Page Should Contain Element` for an explanation about ``message``
@@ -88,10 +91,10 @@ class FormElementKeywords(LibraryComponent):
         See the `Locating elements` section for details about the locator
         syntax.
         """
-        self.assert_page_not_contains(locator, 'checkbox', message, loglevel)
+        self.assert_page_not_contains(locator, "checkbox", message, loglevel)
 
     @keyword
-    def select_checkbox(self, locator):
+    def select_checkbox(self, locator: str):
         """Selects the checkbox identified by ``locator``.
 
         Does nothing if checkbox is already selected.
@@ -99,13 +102,13 @@ class FormElementKeywords(LibraryComponent):
         See the `Locating elements` section for details about the locator
         syntax.
         """
-        self.info("Selecting checkbox '%s'." % locator)
+        self.info(f"Selecting checkbox '{locator}'.")
         element = self._get_checkbox(locator)
         if not element.is_selected():
             element.click()
 
     @keyword
-    def unselect_checkbox(self, locator):
+    def unselect_checkbox(self, locator: str):
         """Removes the selection of checkbox identified by ``locator``.
 
         Does nothing if the checkbox is not selected.
@@ -113,13 +116,15 @@ class FormElementKeywords(LibraryComponent):
         See the `Locating elements` section for details about the locator
         syntax.
         """
-        self.info("Unselecting checkbox '%s'." % locator)
+        self.info(f"Unselecting checkbox '{locator}'.")
         element = self._get_checkbox(locator)
         if element.is_selected():
             element.click()
 
     @keyword
-    def page_should_contain_radio_button(self, locator, message=None, loglevel='TRACE'):
+    def page_should_contain_radio_button(
+        self, locator: str, message: Optional[str] = None, loglevel: str = "TRACE"
+    ):
         """Verifies radio button ``locator`` is found from current page.
 
         See `Page Should Contain Element` for an explanation about ``message``
@@ -129,10 +134,12 @@ class FormElementKeywords(LibraryComponent):
         syntax. When using the default locator strategy, radio buttons are
         searched using ``id``, ``name`` and ``value``.
         """
-        self.assert_page_contains(locator, 'radio button', message, loglevel)
+        self.assert_page_contains(locator, "radio button", message, loglevel)
 
     @keyword
-    def page_should_not_contain_radio_button(self, locator, message=None, loglevel='TRACE'):
+    def page_should_not_contain_radio_button(
+        self, locator: str, message: Optional[str] = None, loglevel: str = "TRACE"
+    ):
         """Verifies radio button ``locator`` is not found from current page.
 
         See `Page Should Contain Element` for an explanation about ``message``
@@ -142,40 +149,40 @@ class FormElementKeywords(LibraryComponent):
         syntax. When using the default locator strategy, radio buttons are
         searched using ``id``, ``name`` and ``value``.
         """
-        self.assert_page_not_contains(locator, 'radio button', message,
-                                      loglevel)
+        self.assert_page_not_contains(locator, "radio button", message, loglevel)
 
     @keyword
-    def radio_button_should_be_set_to(self, group_name, value):
+    def radio_button_should_be_set_to(self, group_name: str, value: str):
         """Verifies radio button group ``group_name`` is set to ``value``.
 
         ``group_name`` is the ``name`` of the radio button group.
         """
-        self.info("Verifying radio button '%s' has selection '%s'."
-                  % (group_name, value))
+        self.info(f"Verifying radio button '{group_name}' has selection '{value}'.")
         elements = self._get_radio_buttons(group_name)
         actual_value = self._get_value_from_radio_buttons(elements)
         if actual_value is None or actual_value != value:
-            raise AssertionError("Selection of radio button '%s' should have "
-                                 "been '%s' but was '%s'."
-                                 % (group_name, value, actual_value))
+            raise AssertionError(
+                f"Selection of radio button '{group_name}' should have "
+                f"been '{value}' but was '{actual_value}'."
+            )
 
     @keyword
-    def radio_button_should_not_be_selected(self, group_name):
+    def radio_button_should_not_be_selected(self, group_name: str):
         """Verifies radio button group ``group_name`` has no selection.
 
         ``group_name`` is the ``name`` of the radio button group.
         """
-        self.info("Verifying radio button '%s' has no selection." % group_name)
+        self.info(f"Verifying radio button '{group_name}' has no selection.")
         elements = self._get_radio_buttons(group_name)
         actual_value = self._get_value_from_radio_buttons(elements)
         if actual_value is not None:
-            raise AssertionError("Radio button group '%s' should not have "
-                                 "had selection, but '%s' was selected."
-                                 % (group_name, actual_value))
+            raise AssertionError(
+                f"Radio button group '{group_name}' should not have "
+                f"had selection, but '{actual_value}' was selected."
+            )
 
     @keyword
-    def select_radio_button(self, group_name, value):
+    def select_radio_button(self, group_name: str, value: str):
         """Sets the radio button group ``group_name`` to ``value``.
 
         The radio button to be selected is located by two arguments:
@@ -187,14 +194,13 @@ class FormElementKeywords(LibraryComponent):
         | `Select Radio Button` | size    | XL    |
         | `Select Radio Button` | contact | email |
         """
-        self.info("Selecting '%s' from radio button '%s'."
-                  % (value, group_name))
+        self.info(f"Selecting '{value}' from radio button '{group_name}'.")
         element = self._get_radio_button_with_value(group_name, value)
         if not element.is_selected():
             element.click()
 
     @keyword
-    def choose_file(self, locator, file_path):
+    def choose_file(self, locator: str, file_path: str):
         """Inputs the ``file_path`` into the file input field ``locator``.
 
         This keyword is most often used to input files into upload forms.
@@ -212,15 +218,15 @@ class FormElementKeywords(LibraryComponent):
         Example:
         | `Choose File` | my_upload_field | ${CURDIR}/trades.csv |
         """
-        self.ctx._running_keyword = 'choose_file'
+        self.ctx._running_keyword = "choose_file"
         try:
-            self.info('Sending %s to browser.' % os.path.abspath(file_path))
+            self.info(f"Sending {os.path.abspath(file_path)} to browser.")
             self.find_element(locator).send_keys(file_path)
         finally:
             self.ctx._running_keyword = None
 
     @keyword
-    def input_password(self, locator, password, clear=True):
+    def input_password(self, locator: str, password: str, clear: bool = True):
         """Types the given password into the text field identified by ``locator``.
 
         See the `Locating elements` section for details about the locator
@@ -244,11 +250,11 @@ class FormElementKeywords(LibraryComponent):
         The `clear` argument is new in SeleniumLibrary 4.0. Hiding password
         logging from Selenium logs is new in SeleniumLibrary 4.2.
         """
-        self.info("Typing password into text field '%s'." % locator)
+        self.info(f"Typing password into text field '{locator}'.")
         self._input_text_into_text_field(locator, password, clear, disable_log=True)
 
     @keyword
-    def input_text(self, locator, text, clear=True):
+    def input_text(self, locator: str, text: str, clear: bool = True):
         """Types the given ``text`` into the text field identified by ``locator``.
 
         When ``clear`` is true, the input element is cleared before
@@ -270,11 +276,13 @@ class FormElementKeywords(LibraryComponent):
         Disabling the file upload the Selenium Grid node and the `clear`
         argument are new in SeleniumLibrary 4.0
         """
-        self.info("Typing text '%s' into text field '%s'." % (text, locator))
+        self.info(f"Typing text '{text}' into text field '{locator}'.")
         self._input_text_into_text_field(locator, text, clear)
 
     @keyword
-    def page_should_contain_textfield(self, locator, message=None, loglevel='TRACE'):
+    def page_should_contain_textfield(
+        self, locator: str, message: Optional[str] = None, loglevel: str = "TRACE"
+    ):
         """Verifies text field ``locator`` is found from current page.
 
         See `Page Should Contain Element` for an explanation about ``message``
@@ -283,10 +291,12 @@ class FormElementKeywords(LibraryComponent):
         See the `Locating elements` section for details about the locator
         syntax.
         """
-        self.assert_page_contains(locator, 'text field', message, loglevel)
+        self.assert_page_contains(locator, "text field", message, loglevel)
 
     @keyword
-    def page_should_not_contain_textfield(self, locator, message=None, loglevel='TRACE'):
+    def page_should_not_contain_textfield(
+        self, locator: str, message: Optional[str] = None, loglevel: str = "TRACE"
+    ):
         """Verifies text field ``locator`` is not found from current page.
 
         See `Page Should Contain Element` for an explanation about ``message``
@@ -295,10 +305,12 @@ class FormElementKeywords(LibraryComponent):
         See the `Locating elements` section for details about the locator
         syntax.
         """
-        self.assert_page_not_contains(locator, 'text field', message, loglevel)
+        self.assert_page_not_contains(locator, "text field", message, loglevel)
 
     @keyword
-    def textfield_should_contain(self, locator, expected, message=None):
+    def textfield_should_contain(
+        self, locator: str, expected: str, message: Optional[str] = None
+    ):
         """Verifies text field ``locator`` contains text ``expected``.
 
         ``message`` can be used to override the default error message.
@@ -306,16 +318,20 @@ class FormElementKeywords(LibraryComponent):
         See the `Locating elements` section for details about the locator
         syntax.
         """
-        actual = self._get_value(locator, 'text field')
+        actual = self._get_value(locator, "text field")
         if expected not in actual:
-            if is_noney(message):
-                message = "Text field '%s' should have contained text '%s' "\
-                          "but it contained '%s'." % (locator, expected, actual)
+            if message is None:
+                message = (
+                    f"Text field '{locator}' should have contained text "
+                    f"'{expected}' but it contained '{actual}'."
+                )
             raise AssertionError(message)
-        self.info("Text field '%s' contains text '%s'." % (locator, expected))
+        self.info(f"Text field '{locator}' contains text '{expected}'.")
 
     @keyword
-    def textfield_value_should_be(self, locator, expected, message=None):
+    def textfield_value_should_be(
+        self, locator: str, expected: str, message: Optional[str] = None
+    ):
         """Verifies text field ``locator`` has exactly text ``expected``.
 
         ``message`` can be used to override default error message.
@@ -323,16 +339,20 @@ class FormElementKeywords(LibraryComponent):
         See the `Locating elements` section for details about the locator
         syntax.
         """
-        actual = self._get_value(locator, 'text field')
+        actual = self._get_value(locator, "text field")
         if actual != expected:
-            if is_noney(message):
-                message = "Value of text field '%s' should have been '%s' "\
-                          "but was '%s'." % (locator, expected, actual)
+            if message is None:
+                message = (
+                    f"Value of text field '{locator}' should have been "
+                    f"'{expected}' but was '{actual}'."
+                )
             raise AssertionError(message)
-        self.info("Content of text field '%s' is '%s'." % (locator, expected))
+        self.info(f"Content of text field '{locator}' is '{expected}'.")
 
     @keyword
-    def textarea_should_contain(self, locator, expected, message=None):
+    def textarea_should_contain(
+        self, locator: str, expected: str, message: Optional[str] = None
+    ):
         """Verifies text area ``locator`` contains text ``expected``.
 
         ``message`` can be used to override default error message.
@@ -340,16 +360,20 @@ class FormElementKeywords(LibraryComponent):
         See the `Locating elements` section for details about the locator
         syntax.
         """
-        actual = self._get_value(locator, 'text area')
+        actual = self._get_value(locator, "text area")
         if expected not in actual:
-            if is_noney(message):
-                message = "Text area '%s' should have contained text '%s' " \
-                          "but it had '%s'." % (locator, expected, actual)
+            if message is None:
+                message = (
+                    f"Text area '{locator}' should have contained text "
+                    f"'{expected}' but it had '{actual}'."
+                )
             raise AssertionError(message)
-        self.info("Text area '%s' contains text '%s'." % (locator, expected))
+        self.info(f"Text area '{locator}' contains text '{expected}'.")
 
     @keyword
-    def textarea_value_should_be(self, locator, expected, message=None):
+    def textarea_value_should_be(
+        self, locator: str, expected: str, message: Optional[str] = None
+    ):
         """Verifies text area ``locator`` has exactly text ``expected``.
 
         ``message`` can be used to override default error message.
@@ -357,16 +381,20 @@ class FormElementKeywords(LibraryComponent):
         See the `Locating elements` section for details about the locator
         syntax.
         """
-        actual = self._get_value(locator, 'text area')
+        actual = self._get_value(locator, "text area")
         if expected != actual:
-            if is_noney(message):
-                message = "Text area '%s' should have had text '%s' " \
-                          "but it had '%s'." % (locator, expected, actual)
+            if message is None:
+                message = (
+                    f"Text area '{locator}' should have had text "
+                    f"'{expected}' but it had '{actual}'."
+                )
             raise AssertionError(message)
-        self.info("Content of text area '%s' is '%s'." % (locator, expected))
+        self.info(f"Content of text area '{locator}' is '{expected}'.")
 
     @keyword
-    def page_should_contain_button(self, locator, message=None, loglevel='TRACE'):
+    def page_should_contain_button(
+        self, locator: str, message: Optional[str] = None, loglevel: str = "TRACE"
+    ):
         """Verifies button ``locator`` is found from current page.
 
         See `Page Should Contain Element` for an explanation about ``message``
@@ -377,12 +405,14 @@ class FormElementKeywords(LibraryComponent):
         searched using ``id``, ``name``, and ``value``.
         """
         try:
-            self.assert_page_contains(locator, 'input', message, loglevel)
+            self.assert_page_contains(locator, "input", message, loglevel)
         except AssertionError:
-            self.assert_page_contains(locator, 'button', message, loglevel)
+            self.assert_page_contains(locator, "button", message, loglevel)
 
     @keyword
-    def page_should_not_contain_button(self, locator, message=None, loglevel='TRACE'):
+    def page_should_not_contain_button(
+        self, locator: str, message: Optional[str] = None, loglevel: str = "TRACE"
+    ):
         """Verifies button ``locator`` is not found from current page.
 
         See `Page Should Contain Element` for an explanation about ``message``
@@ -392,47 +422,50 @@ class FormElementKeywords(LibraryComponent):
         syntax. When using the default locator strategy, buttons are
         searched using ``id``, ``name``, and ``value``.
         """
-        self.assert_page_not_contains(locator, 'button', message, loglevel)
-        self.assert_page_not_contains(locator, 'input', message, loglevel)
+        self.assert_page_not_contains(locator, "button", message, loglevel)
+        self.assert_page_not_contains(locator, "input", message, loglevel)
 
     def _get_value(self, locator, tag):
-        return self.find_element(locator, tag).get_attribute('value')
+        return self.find_element(locator, tag).get_attribute("value")
 
     def _get_checkbox(self, locator):
-        return self.find_element(locator, tag='checkbox')
+        return self.find_element(locator, tag="checkbox")
 
     def _get_radio_buttons(self, group_name):
-        xpath = "xpath://input[@type='radio' and @name='%s']" % group_name
-        self.debug('Radio group locator: ' + xpath)
+        xpath = f"xpath://input[@type='radio' and @name='{group_name}']"
+        self.debug(f"Radio group locator: {xpath}")
         elements = self.find_elements(xpath)
         if not elements:
-            raise ElementNotFound("No radio button with name '%s' found."
-                                  % group_name)
+            raise ElementNotFound(f"No radio button with name '{group_name}' found.")
         return elements
 
     def _get_radio_button_with_value(self, group_name, value):
-        xpath = "xpath://input[@type='radio' and @name='%s' and " \
-                "(@value='%s' or @id='%s')]" % (group_name, value, value)
-        self.debug('Radio group locator: ' + xpath)
+        xpath = (
+            f"xpath://input[@type='radio' and @name='{group_name}' and "
+            f"(@value='{value}' or @id='{value}')]"
+        )
+        self.debug(f"Radio group locator: {xpath}")
         try:
             return self.find_element(xpath)
         except ElementNotFound:
-            raise ElementNotFound("No radio button with name '%s' and "
-                                  "value '%s' found." % (group_name, value))
+            raise ElementNotFound(
+                f"No radio button with name '{group_name}' "
+                f"and value '{value}' found."
+            )
 
     def _get_value_from_radio_buttons(self, elements):
         for element in elements:
             if element.is_selected():
-                return element.get_attribute('value')
+                return element.get_attribute("value")
         return None
 
     def _input_text_into_text_field(self, locator, text, clear=True, disable_log=False):
         element = self.find_element(locator)
-        if is_truthy(clear):
+        if clear:
             element.clear()
         if disable_log:
-            self.info('Temporally setting log level to: NONE')
-            previous_level = BuiltIn().set_log_level('NONE')
+            self.info("Temporally setting log level to: NONE")
+            previous_level = BuiltIn().set_log_level("NONE")
         try:
             element.send_keys(text)
         finally:
