@@ -18,18 +18,16 @@ import os
 from robot.utils import get_link_path
 
 from SeleniumLibrary.base import LibraryComponent, keyword
-from SeleniumLibrary.utils import is_noney
 from SeleniumLibrary.utils.path_formatter import _format_path
 
-DEFAULT_FILENAME_PAGE = 'selenium-screenshot-{index}.png'
-DEFAULT_FILENAME_ELEMENT = 'selenium-element-screenshot-{index}.png'
-EMBED = 'EMBED'
+DEFAULT_FILENAME_PAGE = "selenium-screenshot-{index}.png"
+DEFAULT_FILENAME_ELEMENT = "selenium-element-screenshot-{index}.png"
+EMBED = "EMBED"
 
 
 class ScreenshotKeywords(LibraryComponent):
-
     @keyword
-    def set_screenshot_directory(self, path):
+    def set_screenshot_directory(self, path: str) -> str:
         """Sets the directory for captured screenshots.
 
         ``path`` argument specifies the absolute path to a directory where
@@ -52,7 +50,7 @@ class ScreenshotKeywords(LibraryComponent):
         The persist argument was removed in SeleniumLibrary 3.2 and
         EMBED is new in SeleniumLibrary 4.2.
         """
-        if is_noney(path):
+        if path is None:
             path = None
         elif path.upper() == EMBED:
             path = EMBED
@@ -64,7 +62,7 @@ class ScreenshotKeywords(LibraryComponent):
         return previous
 
     @keyword
-    def capture_page_screenshot(self, filename=DEFAULT_FILENAME_PAGE):
+    def capture_page_screenshot(self, filename: str = DEFAULT_FILENAME_PAGE) -> str:
         """Takes a screenshot of the current page and embeds it into a log file.
 
         ``filename`` argument specifies the name of the file to write the
@@ -106,7 +104,7 @@ class ScreenshotKeywords(LibraryComponent):
         | `File Should Not Exist`   | EMBED                                  |
         """
         if not self.drivers.current:
-            self.info('Cannot capture screenshot because no browser is open.')
+            self.info("Cannot capture screenshot because no browser is open.")
             return
         if self._decide_embedded(filename):
             return self._capture_page_screen_to_log()
@@ -116,7 +114,7 @@ class ScreenshotKeywords(LibraryComponent):
         path = self._get_screenshot_path(filename)
         self._create_directory(path)
         if not self.driver.save_screenshot(path):
-            raise RuntimeError("Failed to save screenshot '{}'.".format(path))
+            raise RuntimeError(f"Failed to save screenshot '{path}'.")
         self._embed_to_log_as_file(path, 800)
         return path
 
@@ -126,7 +124,9 @@ class ScreenshotKeywords(LibraryComponent):
         return EMBED
 
     @keyword
-    def capture_element_screenshot(self, locator, filename=DEFAULT_FILENAME_ELEMENT):
+    def capture_element_screenshot(
+        self, locator: str, filename: str = DEFAULT_FILENAME_ELEMENT
+    ) -> str:
         """Captures a screenshot from the element identified by ``locator`` and embeds it into log file.
 
         See `Capture Page Screenshot` for details about ``filename`` argument.
@@ -147,7 +147,9 @@ class ScreenshotKeywords(LibraryComponent):
         | `Capture Element Screenshot` | id:image_id | EMBED                          |
         """
         if not self.drivers.current:
-            self.info('Cannot capture screenshot from element because no browser is open.')
+            self.info(
+                "Cannot capture screenshot from element because no browser is open."
+            )
             return
         element = self.find_element(locator, required=True)
         if self._decide_embedded(filename):
@@ -158,7 +160,7 @@ class ScreenshotKeywords(LibraryComponent):
         path = self._get_screenshot_path(filename)
         self._create_directory(path)
         if not element.screenshot(path):
-            raise RuntimeError("Failed to save element screenshot '{}'.".format(path))
+            raise RuntimeError(f"Failed to save element screenshot '{path}'.")
         self._embed_to_log_as_file(path, 400)
         return path
 
@@ -176,9 +178,15 @@ class ScreenshotKeywords(LibraryComponent):
 
     def _decide_embedded(self, filename):
         filename = filename.lower()
-        if filename == DEFAULT_FILENAME_PAGE and self._screenshot_root_directory == EMBED:
+        if (
+            filename == DEFAULT_FILENAME_PAGE
+            and self._screenshot_root_directory == EMBED
+        ):
             return True
-        if filename == DEFAULT_FILENAME_ELEMENT and self._screenshot_root_directory == EMBED:
+        if (
+            filename == DEFAULT_FILENAME_ELEMENT
+            and self._screenshot_root_directory == EMBED
+        ):
             return True
         if filename == EMBED.lower():
             return True
@@ -189,7 +197,7 @@ class ScreenshotKeywords(LibraryComponent):
             directory = self._screenshot_root_directory or self.log_dir
         else:
             directory = self.log_dir
-        filename = filename.replace('/', os.sep)
+        filename = filename.replace("/", os.sep)
         index = 0
         while True:
             index += 1
@@ -207,14 +215,19 @@ class ScreenshotKeywords(LibraryComponent):
     def _embed_to_log_as_base64(self, screenshot_as_base64, width):
         # base64 image is shown as on its own row and thus previous row is closed on
         # purpose. Depending on Robot's log structure is a bit risky.
-        self.info('</td></tr><tr><td colspan="3">'
-                  '<img alt="screenshot" class="robot-seleniumlibrary-screenshot" '
-                  'src="data:image/png;base64,{screenshot_data}" width="{width}px">'
-                  .format(screenshot_data=screenshot_as_base64, width=width), html=True)
+        self.info(
+            '</td></tr><tr><td colspan="3">'
+            '<img alt="screenshot" class="robot-seleniumlibrary-screenshot" '
+            f'src="data:image/png;base64,{screenshot_as_base64}" width="{width}px">',
+            html=True,
+        )
 
     def _embed_to_log_as_file(self, path, width):
         # Image is shown on its own row and thus previous row is closed on
         # purpose. Depending on Robot's log structure is a bit risky.
-        self.info('</td></tr><tr><td colspan="3">'
-                  '<a href="{src}"><img src="{src}" width="{width}px"></a>'
-                  .format(src=get_link_path(path, self.log_dir), width=width), html=True)
+        src = get_link_path(path, self.log_dir)
+        self.info(
+            '</td></tr><tr><td colspan="3">'
+            f'<a href="{src}"><img src="{src}" width="{width}px"></a>',
+            html=True,
+        )
