@@ -13,17 +13,17 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from typing import List, Optional
 
 from selenium.webdriver.support.ui import Select
 
 from SeleniumLibrary.base import LibraryComponent, keyword
-from SeleniumLibrary.utils import is_truthy, plural_or_not as s
+from SeleniumLibrary.utils import is_truthy, plural_or_not
 
 
 class SelectElementKeywords(LibraryComponent):
-
     @keyword
-    def get_list_items(self, locator, values=False):
+    def get_list_items(self, locator: str, values: bool = False) -> List[str]:
         """Returns all labels or values of selection list ``locator``.
 
         See the `Locating elements` section for details about the locator
@@ -46,7 +46,7 @@ class SelectElementKeywords(LibraryComponent):
             return self._get_labels(options)
 
     @keyword
-    def get_selected_list_label(self, locator):
+    def get_selected_list_label(self, locator: str) -> str:
         """Returns the label of selected option from selection list ``locator``.
 
         If there are multiple selected options, the label of the first option
@@ -59,7 +59,7 @@ class SelectElementKeywords(LibraryComponent):
         return select.first_selected_option.text
 
     @keyword
-    def get_selected_list_labels(self, locator):
+    def get_selected_list_labels(self, locator: str) -> List[str]:
         """Returns labels of selected options from selection list ``locator``.
 
         Starting from SeleniumLibrary 3.0, returns an empty list if there
@@ -72,7 +72,7 @@ class SelectElementKeywords(LibraryComponent):
         return self._get_labels(options)
 
     @keyword
-    def get_selected_list_value(self, locator):
+    def get_selected_list_value(self, locator: str) -> str:
         """Returns the value of selected option from selection list ``locator``.
 
         If there are multiple selected options, the value of the first option
@@ -82,10 +82,10 @@ class SelectElementKeywords(LibraryComponent):
         syntax.
         """
         select = self._get_select_list(locator)
-        return select.first_selected_option.get_attribute('value')
+        return select.first_selected_option.get_attribute("value")
 
     @keyword
-    def get_selected_list_values(self, locator):
+    def get_selected_list_values(self, locator: str) -> List[str]:
         """Returns values of selected options from selection list ``locator``.
 
         Starting from SeleniumLibrary 3.0, returns an empty list if there
@@ -98,7 +98,7 @@ class SelectElementKeywords(LibraryComponent):
         return self._get_values(options)
 
     @keyword
-    def list_selection_should_be(self, locator, *expected):
+    def list_selection_should_be(self, locator: str, *expected: str):
         """Verifies selection list ``locator`` has ``expected`` options selected.
 
         It is possible to give expected options both as visible labels and
@@ -117,40 +117,45 @@ class SelectElementKeywords(LibraryComponent):
         | `List Selection Should Be` | gender    | Female          |        |
         | `List Selection Should Be` | interests | Test Automation | Python |
         """
-        self.info("Verifying list '%s' has option%s [ %s ] selected."
-                  % (locator, s(expected), ' | '.join(expected)))
+        self.info(
+            f"Verifying list '{locator}' has option{plural_or_not(expected)} "
+            f"[ {' | '.join(expected)} ] selected."
+        )
         self.page_should_contain_list(locator)
         options = self._get_selected_options(locator)
         labels = self._get_labels(options)
         values = self._get_values(options)
         if sorted(expected) not in [sorted(labels), sorted(values)]:
-            raise AssertionError("List '%s' should have had selection [ %s ] "
-                                 "but selection was [ %s ]."
-                                 % (locator, ' | '.join(expected),
-                                    self._format_selection(labels, values)))
+            raise AssertionError(
+                f"List '{locator}' should have had selection [ {' | '.join(expected)} ] "
+                f"but selection was [ {self._format_selection(labels, values)} ]."
+            )
 
     def _format_selection(self, labels, values):
-        return ' | '.join('%s (%s)' % (label, value)
-                          for label, value in zip(labels, values))
+        return " | ".join(f"{label} ({value})" for label, value in zip(labels, values))
 
     @keyword
-    def list_should_have_no_selections(self, locator):
+    def list_should_have_no_selections(self, locator: str):
         """Verifies selection list ``locator`` has no options selected.
 
         See the `Locating elements` section for details about the locator
         syntax.
         """
-        self.info("Verifying list '%s' has no selections." % locator)
+        self.info(f"Verifying list '{locator}' has no selections.")
         options = self._get_selected_options(locator)
         if options:
-            selection = self._format_selection(self._get_labels(options),
-                                               self._get_values(options))
-            raise AssertionError("List '%s' should have had no selection "
-                                 "but selection was [ %s ]."
-                                 % (locator, selection))
+            selection = self._format_selection(
+                self._get_labels(options), self._get_values(options)
+            )
+            raise AssertionError(
+                f"List '{locator}' should have had no selection "
+                f"but selection was [ {selection} ]."
+            )
 
     @keyword
-    def page_should_contain_list(self, locator, message=None, loglevel='TRACE'):
+    def page_should_contain_list(
+        self, locator: str, message: Optional[str] = None, loglevel: str = "TRACE"
+    ):
         """Verifies selection list ``locator`` is found from current page.
 
         See `Page Should Contain Element` for an explanation about ``message``
@@ -159,10 +164,12 @@ class SelectElementKeywords(LibraryComponent):
         See the `Locating elements` section for details about the locator
         syntax.
         """
-        self.assert_page_contains(locator, 'list', message, loglevel)
+        self.assert_page_contains(locator, "list", message, loglevel)
 
     @keyword
-    def page_should_not_contain_list(self, locator, message=None, loglevel='TRACE'):
+    def page_should_not_contain_list(
+        self, locator: str, message: Optional[str] = None, loglevel: str = "TRACE"
+    ):
         """Verifies selection list ``locator`` is not found from current page.
 
         See `Page Should Contain Element` for an explanation about ``message``
@@ -171,25 +178,26 @@ class SelectElementKeywords(LibraryComponent):
         See the `Locating elements` section for details about the locator
         syntax.
         """
-        self.assert_page_not_contains(locator, 'list', message, loglevel)
+        self.assert_page_not_contains(locator, "list", message, loglevel)
 
     @keyword
-    def select_all_from_list(self, locator):
+    def select_all_from_list(self, locator: str):
         """Selects all options from multi-selection list ``locator``.
 
         See the `Locating elements` section for details about the locator
         syntax.
         """
-        self.info("Selecting all options from list '%s'." % locator)
+        self.info(f"Selecting all options from list '{locator}'.")
         select = self._get_select_list(locator)
         if not select.is_multiple:
-            raise RuntimeError("'Select All From List' works only with "
-                               "multi-selection lists.")
-        for i in range(len(select.options)):
-            select.select_by_index(i)
+            raise RuntimeError(
+                "'Select All From List' works only with multi-selection lists."
+            )
+        for index in range(len(select.options)):
+            select.select_by_index(index)
 
     @keyword
-    def select_from_list_by_index(self, locator, *indexes):
+    def select_from_list_by_index(self, locator: str, *indexes: str):
         """Selects options from selection list ``locator`` by ``indexes``.
 
         Indexes of list options start from 0.
@@ -204,15 +212,17 @@ class SelectElementKeywords(LibraryComponent):
         """
         if not indexes:
             raise ValueError("No indexes given.")
-        self.info("Selecting options from selection list '%s' by index%s %s."
-                  % (locator, '' if len(indexes) == 1 else 'es',
-                     ', '.join(indexes)))
+        plural = "" if len(indexes) == 1 else "es"
+        self.info(
+            f"Selecting options from selection list '{locator}' "
+            f"by index{plural} {', '.join(indexes)}."
+        )
         select = self._get_select_list(locator)
         for index in indexes:
             select.select_by_index(int(index))
 
     @keyword
-    def select_from_list_by_value(self, locator, *values):
+    def select_from_list_by_value(self, locator: str, *values: str):
         """Selects options from selection list ``locator`` by ``values``.
 
         If more than one option is given for a single-selection list,
@@ -225,14 +235,16 @@ class SelectElementKeywords(LibraryComponent):
         """
         if not values:
             raise ValueError("No values given.")
-        self.info("Selecting options from selection list '%s' by value%s %s."
-                  % (locator, s(values), ', '.join(values)))
+        self.info(
+            f"Selecting options from selection list '{locator}' by "
+            f"value{plural_or_not(values)} {', '.join(values)}."
+        )
         select = self._get_select_list(locator)
         for value in values:
             select.select_by_value(value)
 
     @keyword
-    def select_from_list_by_label(self, locator, *labels):
+    def select_from_list_by_label(self, locator: str, *labels: str):
         """Selects options from selection list ``locator`` by ``labels``.
 
         If more than one option is given for a single-selection list,
@@ -245,14 +257,16 @@ class SelectElementKeywords(LibraryComponent):
         """
         if not labels:
             raise ValueError("No labels given.")
-        self.info("Selecting options from selection list '%s' by label%s %s."
-                  % (locator, s(labels), ', '.join(labels)))
+        self.info(
+            f"Selecting options from selection list '{locator}' "
+            f"by label{plural_or_not(labels)} {', '.join(labels)}."
+        )
         select = self._get_select_list(locator)
         for label in labels:
             select.select_by_visible_text(label)
 
     @keyword
-    def unselect_all_from_list(self, locator):
+    def unselect_all_from_list(self, locator: str):
         """Unselects all options from multi-selection list ``locator``.
 
         See the `Locating elements` section for details about the locator
@@ -260,15 +274,16 @@ class SelectElementKeywords(LibraryComponent):
 
         New in SeleniumLibrary 3.0.
         """
-        self.info("Unselecting all options from list '%s'." % locator)
+        self.info(f"Unselecting all options from list '{locator}'.")
         select = self._get_select_list(locator)
         if not select.is_multiple:
-            raise RuntimeError("Un-selecting options works only with "
-                               "multi-selection lists.")
+            raise RuntimeError(
+                "Un-selecting options works only with multi-selection lists."
+            )
         select.deselect_all()
 
     @keyword
-    def unselect_from_list_by_index(self, locator, *indexes):
+    def unselect_from_list_by_index(self, locator: str, *indexes: str):
         """Unselects options from selection list ``locator`` by ``indexes``.
 
         Indexes of list options start from 0. This keyword works only with
@@ -279,18 +294,21 @@ class SelectElementKeywords(LibraryComponent):
         """
         if not indexes:
             raise ValueError("No indexes given.")
-        self.info("Un-selecting options from selection list '%s' by index%s "
-                  "%s." % (locator, '' if len(indexes) == 1 else 'es',
-                           ', '.join(indexes)))
+        plurar = "" if len(indexes) == 1 else "es"
+        self.info(
+            f"Un-selecting options from selection list '{locator}' by index{plurar} "
+            f"{', '.join(indexes)}."
+        )
         select = self._get_select_list(locator)
         if not select.is_multiple:
-            raise RuntimeError("Un-selecting options works only with "
-                               "multi-selection lists.")
+            raise RuntimeError(
+                "Un-selecting options works only with multi-selection lists."
+            )
         for index in indexes:
             select.deselect_by_index(int(index))
 
     @keyword
-    def unselect_from_list_by_value(self, locator, *values):
+    def unselect_from_list_by_value(self, locator: str, *values: str):
         """Unselects options from selection list ``locator`` by ``values``.
 
         This keyword works only with multi-selection lists.
@@ -300,17 +318,20 @@ class SelectElementKeywords(LibraryComponent):
         """
         if not values:
             raise ValueError("No values given.")
-        self.info("Un-selecting options from selection list '%s' by value%s "
-                  "%s." % (locator, s(values), ', '.join(values)))
+        self.info(
+            f"Un-selecting options from selection list '{locator}' by "
+            f"value{plural_or_not(values)} {', '.join(values)}."
+        )
         select = self._get_select_list(locator)
         if not select.is_multiple:
-            raise RuntimeError("Un-selecting options works only with "
-                               "multi-selection lists.")
+            raise RuntimeError(
+                "Un-selecting options works only with multi-selection lists."
+            )
         for value in values:
             select.deselect_by_value(value)
 
     @keyword
-    def unselect_from_list_by_label(self, locator, *labels):
+    def unselect_from_list_by_label(self, locator: str, *labels: str):
         """Unselects options from selection list ``locator`` by ``labels``.
 
         This keyword works only with multi-selection lists.
@@ -320,17 +341,20 @@ class SelectElementKeywords(LibraryComponent):
         """
         if not labels:
             raise ValueError("No labels given.")
-        self.info("Un-selecting options from selection list '%s' by label%s "
-                  "%s." % (locator, s(labels), ', '.join(labels)))
+        self.info(
+            f"Un-selecting options from selection list '{locator}' by "
+            f"label{plural_or_not(labels)} {', '.join(labels)}."
+        )
         select = self._get_select_list(locator)
         if not select.is_multiple:
-            raise RuntimeError("Un-selecting options works only with "
-                               "multi-selection lists.")
+            raise RuntimeError(
+                "Un-selecting options works only with multi-selection lists."
+            )
         for label in labels:
             select.deselect_by_visible_text(label)
 
     def _get_select_list(self, locator):
-        el = self.find_element(locator, tag='list')
+        el = self.find_element(locator, tag="list")
         return Select(el)
 
     def _get_options(self, locator):
@@ -343,4 +367,4 @@ class SelectElementKeywords(LibraryComponent):
         return [opt.text for opt in options]
 
     def _get_values(self, options):
-        return [opt.get_attribute('value') for opt in options]
+        return [opt.get_attribute("value") for opt in options]
