@@ -14,16 +14,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from robot.utils import plural_or_not, secs_to_timestr, timestr_to_secs
+from robot.utils import plural_or_not, secs_to_timestr, timestr_to_secs  # noqa
 
-from .librarylistener import LibraryListener
-from .types import is_falsy, is_noney, is_string, is_truthy, PY3, WINDOWS
+from .librarylistener import LibraryListener  # noqa
+from .types import is_falsy, is_noney, is_string, is_truthy, WINDOWS, _convert_timeout  # noqa
 
 
-def escape_xpath_value(value):
-    if '"' in value and '\'' in value:
-        parts_wo_apos = value.split('\'')
-        return "concat('%s')" % "', \"'\", '".join(parts_wo_apos)
-    if '\'' in value:
-        return "\"%s\"" % value
-    return "'%s'" % value
+def escape_xpath_value(value: str):
+    value = str(value)
+    if '"' in value and "'" in value:
+        parts_wo_apos = value.split("'")
+        escaped = "', \"'\", '".join(parts_wo_apos)
+        return f"concat('{escaped}')"
+    if "'" in value:
+        return f'"{value}"'
+    return f"'{value}'"
